@@ -20,6 +20,7 @@ from Products.CMFCore.utils import getToolByName
 from Products.statusmessages.interfaces import IStatusMessage
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.MailHost.MailHost import MailHostError
+from plonetheme.nuplone.tiles.analytics import trigger_extra_pageview
 from .interfaces import IClientSkinLayer
 from .utils import CreateEmailTo
 from .utils import setLanguage
@@ -86,6 +87,8 @@ class Login(grok.View):
             if isinstance(account, Account) and \
                     account.getUserName() == reply.get("__ac_name", '').lower():
                 self.login(account, bool(self.request.form.get('remember')))
+                v_url = urlparse.urlsplit(self.url()+'/success').path
+                trigger_extra_pageview(self.request, v_url)
 
                 if checkTermsAndConditions() and \
                         not approvedTermsAndConditions(account):
@@ -216,6 +219,8 @@ class Register(grok.View):
                                 password=reply.get("password1"))
         Session().add(account)
         log.info("Registered new account %s", loginname)
+        v_url = urlparse.urlsplit(self.url()+'/success').path
+        trigger_extra_pageview(self.request, v_url)
         return account
 
     def update(self):
