@@ -9,6 +9,13 @@ TAG = re.compile(u"<.*?>")
 
 REGION_NAMES = {
         "eu": _(u"European Union"),
+        
+        # This are areas whose country codes have not stabilized enough
+        # to have arrived in the Unicode consortiums translations,
+        # or were we use and old/incorrect country code.
+        "CS": _(u"Kosovo"),
+        "ME": _(u"Montenegro"),
+        "RS": _(u"Republic of Serbia"),
         }
 
 
@@ -75,7 +82,10 @@ def summarizeCountries(container, request, current_country=None,
         if permission and not checkPermission(country, permission):
             continue
 
-        country_type = getattr(country, "country_type", "eu-member")
+
+        country_type = getattr(country, "country_type", "country")
+        if country_type != 'region':
+            country_type = 'country'
         countries = result.setdefault(country_type, [])
         countries.append({"id": country.id,
                           "title": getRegionTitle(request, country.id,
